package org.bluej.extensions.mainrunner;

import bluej.extensions2.BlueJ;
import bluej.extensions2.Extension;

import java.net.URL;

/**
 * An extension to allow direct invocation of a main method.
 * If a class contains a properly declared main method, this extensions adds a menu item "Run Main Method"
 *  which directly invokes it. This makes the main method much more obvious, if that suits your style,
 *  and also helps you get the declaration right.
 * If it's not "public static void main(String [] args)" you won't see the menu item.
 *
 * @author Ian Utting (original version)
 * @author Pierre Weill-Tessier (upgrate for BlueJ 5)
 */
public class MainRunner extends Extension {
    public MainRunner() {
    }

    public void startup(BlueJ bluej) {
        bluej.setMenuGenerator(new MenuBuilder());
    }

    public boolean isCompatible() {
        return getExtensionsAPIVersionMajor() >= 2;
    }

    public String getVersion() {
        return "2.0.1";
    }

    public String getName() {
        return "Main Program Runner";
    }

    public String getDescription() {
        return "Run an application via its main method.";
    }

    public URL getURL() {
        return null;
    }
}
